[asterisk-commits] kmoore: branch group/bridge_construction r384745 - /team/group/bridge_constru...
SVN commits to the Asterisk project
asterisk-commits at lists.digium.com
Thu Apr 4 11:25:12 CDT 2013
Author: kmoore
Date: Thu Apr 4 11:25:09 2013
New Revision: 384745
URL: http://svnview.digium.com/svn/asterisk?view=rev&rev=384745
Log:
Strip ast_ prefixes from static functions
Modified:
team/group/bridge_construction/main/bridging.c
Modified: team/group/bridge_construction/main/bridging.c
URL: http://svnview.digium.com/svn/asterisk/team/group/bridge_construction/main/bridging.c?view=diff&rev=384745&r1=384744&r2=384745
==============================================================================
--- team/group/bridge_construction/main/bridging.c (original)
+++ team/group/bridge_construction/main/bridging.c Thu Apr 4 11:25:09 2013
@@ -108,7 +108,7 @@
*
* \return Nothing
*/
-static void ast_bridge_manager_service_req(struct ast_bridge *bridge)
+static void bridge_manager_service_req(struct ast_bridge *bridge)
{
struct bridge_manager_request *request;
@@ -268,7 +268,7 @@
*
* \return Nothing
*/
-static void ast_bridge_queue_action_nodup(struct ast_bridge *bridge, struct ast_frame *action)
+static void bridge_queue_action_nodup(struct ast_bridge *bridge, struct ast_frame *action)
{
ast_debug(1, "Bridge %s: queueing action type:%d sub:%d\n",
bridge->uniqueid, action->frametype, action->subclass.integer);
@@ -276,7 +276,7 @@
ast_bridge_lock(bridge);
AST_LIST_INSERT_TAIL(&bridge->action_queue, action, frame_list);
ast_bridge_unlock(bridge);
- ast_bridge_manager_service_req(bridge);
+ bridge_manager_service_req(bridge);
}
int ast_bridge_queue_action(struct ast_bridge *bridge, struct ast_frame *action)
@@ -287,7 +287,7 @@
if (!dup) {
return -1;
}
- ast_bridge_queue_action_nodup(bridge, dup);
+ bridge_queue_action_nodup(bridge, dup);
return 0;
}
@@ -388,7 +388,7 @@
*
* \return Nothing
*/
-static void ast_bridge_channel_pull(struct ast_bridge_channel *bridge_channel)
+static void bridge_channel_pull(struct ast_bridge_channel *bridge_channel)
{
struct ast_bridge *bridge = bridge_channel->bridge;
@@ -434,7 +434,7 @@
*
* \return Nothing
*/
-static void ast_bridge_channel_push(struct ast_bridge_channel *bridge_channel)
+static void bridge_channel_push(struct ast_bridge_channel *bridge_channel)
{
struct ast_bridge *bridge = bridge_channel->bridge;
struct ast_bridge_channel *swap;
@@ -488,7 +488,7 @@
}
if (swap) {
ast_bridge_change_state(swap, AST_BRIDGE_CHANNEL_STATE_HANGUP);
- ast_bridge_channel_pull(swap);
+ bridge_channel_pull(swap);
}
bridge->reconfigured = 1;
@@ -646,7 +646,7 @@
*
* \param bridge_channel Bridge channel the notification was received on
*/
-static void ast_bridge_handle_trip(struct ast_bridge_channel *bridge_channel)
+static void bridge_handle_trip(struct ast_bridge_channel *bridge_channel)
{
struct ast_frame *frame;
@@ -1353,7 +1353,7 @@
if (old_technology->destroy) {
ast_debug(1, "Bridge %s: deferring %s technology destructor\n",
bridge->uniqueid, old_technology->name);
- ast_bridge_queue_action_nodup(bridge, deferred_action);
+ bridge_queue_action_nodup(bridge, deferred_action);
} else {
ast_debug(1, "Bridge %s: calling %s technology destructor\n",
bridge->uniqueid, old_technology->name);
@@ -1371,8 +1371,8 @@
* \param bridge Reconfigured bridge.
*
* \details
* After a series of ast_bridge_channel_push and
* ast_bridge_channel_pull calls, you need to call this function
* to cause the bridge to complete restruturing for the change
* in the channel makeup of the bridge.
*
@@ -1380,7 +1380,7 @@
*
* \return Nothing
*/
-static void ast_bridge_reconfigured(struct ast_bridge *bridge)
+static void bridge_reconfigured(struct ast_bridge *bridge)
{
if (!bridge->reconfigured) {
return;
@@ -1917,7 +1917,7 @@
&& bridge_channel->state == AST_BRIDGE_CHANNEL_STATE_WAIT) {
if (chan) {
bridge_channel_handle_interval(bridge_channel);
- ast_bridge_handle_trip(bridge_channel);
+ bridge_handle_trip(bridge_channel);
} else if (-1 < outfd) {
bridge_channel_handle_write(bridge_channel);
}
@@ -1949,8 +1949,8 @@
bridge_channel->bridge->callid = ast_read_threadstorage_callid();
}
- ast_bridge_channel_push(bridge_channel);
- ast_bridge_reconfigured(bridge_channel->bridge);
+ bridge_channel_push(bridge_channel);
+ bridge_reconfigured(bridge_channel->bridge);
/*
* Indicate a source change since this channel is entering the
@@ -1972,8 +1972,8 @@
}
bridge_channel_lock_bridge(bridge_channel);
- ast_bridge_channel_pull(bridge_channel);
- ast_bridge_reconfigured(bridge_channel->bridge);
+ bridge_channel_pull(bridge_channel);
+ bridge_reconfigured(bridge_channel->bridge);
/* See if we need to dissolve the bridge itself if they hung up */
switch (bridge_channel->state) {
@@ -2417,7 +2417,7 @@
/* BUGBUG this needs more work. The channels need to be made compatible again if the formats change. The bridge_channel thread needs to monitor for this case. */
/* The channel we want to notify is still in a bridge. */
bridge->v_table->notify_masquerade(bridge, bridge_channel);
- ast_bridge_reconfigured(bridge);
+ bridge_reconfigured(bridge);
}
ast_bridge_unlock(bridge);
ao2_ref(bridge_channel, -1);
@@ -2685,7 +2685,7 @@
* this operation is completed. The caller must explicitly call
* ast_bridge_destroy().
*/
-static void ast_bridge_merge_do(struct ast_bridge *bridge1, struct ast_bridge *bridge2)
+static void bridge_merge_do(struct ast_bridge *bridge1, struct ast_bridge *bridge2)
{
struct ast_bridge_channel *bridge_channel;
@@ -2694,7 +2694,7 @@
/* Move channels from bridge2 over to bridge1 */
while ((bridge_channel = AST_LIST_FIRST(&bridge2->channels))) {
- ast_bridge_channel_pull(bridge_channel);
+ bridge_channel_pull(bridge_channel);
/* Point to new bridge.*/
ao2_ref(bridge1, +1);
@@ -2703,10 +2703,10 @@
ast_bridge_channel_unlock(bridge_channel);
ao2_ref(bridge2, -1);
- ast_bridge_channel_push(bridge_channel);
- }
- ast_bridge_reconfigured(bridge1);
- ast_bridge_reconfigured(bridge2);
+ bridge_channel_push(bridge_channel);
+ }
+ bridge_reconfigured(bridge1);
+ bridge_reconfigured(bridge2);
ast_debug(1, "Merged bridge %s into bridge %s\n",
bridge2->uniqueid, bridge1->uniqueid);
@@ -2743,7 +2743,7 @@
} else {
++bridge1->inhibit_merge;
++bridge2->inhibit_merge;
- ast_bridge_merge_do(bridge1, bridge2);
+ bridge_merge_do(bridge1, bridge2);
--bridge2->inhibit_merge;
--bridge1->inhibit_merge;
res = 0;
More information about the asterisk-commits
mailing list
@@ -1371,8 +1371,8 @@
*
* \details
- * After a series of ast_bridge_channel_push and
- * ast_bridge_channel_pull calls, you need to call this function
+ * After a series of bridge_channel_push and
+ * bridge_channel_pull calls, you need to call this function
* to cause the bridge to complete restruturing for the change
* in the channel makeup of the bridge.